package enum

// MallCouponType 优惠券类型
type MallCouponType int

const (
	MallCouponTypeImmediate     MallCouponType = iota + 1 // 立减
	MallCouponTypeReachReduce                             // 满减
	MallCouponTypeReachDiscount                           // 满折
)

func (em MallCouponType) String() string {
	switch em {
	case MallCouponTypeImmediate:
		return "立减券"
	case MallCouponTypeReachReduce:
		return "满减券"
	case MallCouponTypeReachDiscount:
		return "折扣券"
	default:
		return "未知类型"
	}
}

// MallCouponSendWay 发放形式
type MallCouponSendWay int

const (
	MallCouponSendWayPositive MallCouponSendWay = iota + 1
	MallCouponSendWayManual
	ActCouponSendWayReg
)

func (em MallCouponSendWay) String() string {
	switch em {
	case MallCouponSendWayPositive:
		return "主动发放"
	case MallCouponSendWayManual:
		return "手动领取"
	case ActCouponSendWayReg:
		return "注册发放"
	default:
		return "未知类型"
	}
}

// MallCouponSendTimeType 发放时间类型
type MallCouponSendTimeType int

const (
	MallCouponSendTimeTypeImmediate MallCouponSendTimeType = iota + 1
	MallCouponSendTimeTypeTiming
)

func (em MallCouponSendTimeType) String() string {
	switch em {
	case MallCouponSendTimeTypeImmediate:
		return "立即发放"
	case MallCouponSendTimeTypeTiming:
		return "定时"
	default:
		return "未知类型"
	}
}

// MallCouponSendUserType 发放用户
type MallCouponSendUserType int

const (
	MallCouponSendUserTypeAll MallCouponSendUserType = iota + 1
	MallCouponSendUserTypeSpecify
)

func (em MallCouponSendUserType) String() string {
	switch em {
	case MallCouponSendUserTypeAll:
		return "全部用户"
	case MallCouponSendUserTypeSpecify:
		return "指定用户"
	default:
		return "未知类型"
	}
}

// MallCouponValidTimeType 有效时间
type MallCouponValidTimeType int

const (
	MallCouponValidTimeTypeFix  MallCouponValidTimeType = iota + 1 // 固定日期
	MallCouponValidTimeTypeXDay                                    // 领取后x天有效
)

func (em MallCouponValidTimeType) String() string {
	switch em {
	case MallCouponValidTimeTypeFix:
		return "固定日期"
	case MallCouponValidTimeTypeXDay:
		return "领取日起x天内"
	default:
		return "未知类型"
	}
}

// MallCouponUseRule 使用规则
type MallCouponUseRule int

const (
	MallCouponUseRuleAll             MallCouponUseRule = iota + 1 // 全部商品可用
	MallCouponUseRuleSpecifyGoods                                 // 仅可用于指定商品
	MallCouponUseRuleSpecifyActivity                              // 可用于活动类型
	ActCouponUsePhone                                             // 可用于权益卡话费
)

func (em MallCouponUseRule) String() string {
	switch em {
	case MallCouponUseRuleAll:
		return "全部商品可用"
	case MallCouponUseRuleSpecifyGoods:
		return "仅可用于指定商品"
	case MallCouponUseRuleSpecifyActivity:
		return "可用于活动类型"
	case ActCouponUsePhone:
		return "可用于权益卡话费"
	default:
		return "未知类型"
	}
}

type MallCouponUseActivityType int

const (
	MallCouponUseActivityTypeForGroup MallCouponUseActivityType = iota + 1
	MallCouponUseActivityTypeForSecondKill
	MallCouponUseActivityTypeForBargain
)

func (em MallCouponUseActivityType) String() string {
	switch em {
	case MallCouponUseActivityTypeForGroup:
		return "拼团活动"
	case MallCouponUseActivityTypeForSecondKill:
		return "秒杀活动"
	case MallCouponUseActivityTypeForBargain:
		return "砍价活动"
	default:
		return "未知类型"
	}
}

type MallCouponSendState int

const (
	MallCouponSendStateUnProvide MallCouponSendState = iota + 1 // 未发放
	MallCouponSendStateProvide                                  // 已发放
	MallCouponSendStateProviding                                // 发放中
)

func (em MallCouponSendState) String() string {
	switch em {
	case MallCouponSendStateUnProvide:
		return "未发放"
	case MallCouponSendStateProvide:
		return "已发放"
	case MallCouponSendStateProviding:
		return "发放中"
	default:
		return "未知类型"
	}
}

type MallUserCouponUseState int

const (
	MallUserCouponUseStateUnUse   MallUserCouponUseState = iota // 未使用
	MallUserCouponUseStateUsed                                  // 已使用
	MallUserCouponUseStateUnValid                               // 失效
)

func (em MallUserCouponUseState) String() string {
	switch em {
	case MallUserCouponUseStateUnUse:
		return "未使用"
	case MallUserCouponUseStateUsed:
		return "已使用"
	case MallUserCouponUseStateUnValid:
		return "失效"
	default:
		return "未知类型"
	}
}
